"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getWebpackConfig = void 0;
const path_1 = __importDefault(require("path"));
// Config extends:
// - https://github.com/storybookjs/storybook/blob/master/lib/core/src/server/preview/base-webpack.config.js
// - https://github.com/storybookjs/storybook/blob/master/app/vue/src/server/framework-preset-vue.ts
function getWebpackConfig(config, extras) {
    // Merge Webpack plugins
    const nuxtFilteredPlugins = [
        'VueSSRClientPlugin',
        'ExtractCSS',
        // 'HotModuleReplacementPlugin',
        'HtmlWebpackPlugin'
    ];
    const nuxtFilteredEntries = [
        'webpack-hot-middleware',
        '.nuxt-storybook/client.js',
        'eventsource-polyfill'
    ];
    const storybookValidPlugins = [
        'VirtualModulesPlugin',
        'HtmlWebpackPlugin',
        'DefinePlugin' // Required because of https://storybook.js.org/docs/vue/configure/environment-variables
    ];
    config.entry = [
        ...extras.nuxtWebpackConfig.entry.app.filter(p => !nuxtFilteredEntries.some(np => p.includes(np))),
        ...config.entry
    ];
    // @ts-ignore
    // replace entry point
    const modules = config.plugins.find(p => p.constructor.name === 'VirtualModulesPlugin')._staticModules;
    Object.keys(modules).forEach((key) => {
        modules[key] = modules[key].replace(/@storybook\/vue/g, '~~/.nuxt-storybook/storybook/entry');
    });
    config.plugins = [
        ...config.plugins.filter(p => storybookValidPlugins.some(np => p.constructor.name === np)),
        ...extras.nuxtWebpackConfig.plugins.filter(p => !nuxtFilteredPlugins.some(np => p.constructor.name === np))
    ];
    const rules = config.module.rules
        .filter(rule => !/css|svg|mp/.test(rule.test.toString()) && !/vue-loader/.test(String(rule.loader)));
    // Nuxt rules
    config.module.rules = [
        ...rules,
        ...extras.nuxtWebpackConfig.module.rules
    ];
    // Aliases
    const buildDir = extras.nuxt.options.buildDir;
    config.resolve.alias = Object.assign(Object.assign(Object.assign(Object.assign({}, extras.nuxtWebpackConfig.resolve.alias), config.resolve.alias), { '~storybook': path_1.default.resolve(__dirname, '../storybook') }), extras.nuxtBuilder.plugins.reduce((map, plugin) => (Object.assign(Object.assign({}, map), { [plugin.name]: path_1.default.resolve(buildDir, plugin.src) })), {}));
    // Return the altered config
    return config;
}
exports.getWebpackConfig = getWebpackConfig;
